function [delosw] = getdelo_latbin(coords)
%this function finds delo of seawater from the LeGrande & Schimdt 2006 modern database, for matching to paleodata.
%INPUT: coords, an N by 2 matrix of paleolocation [longitude latitude]
%OUTPUT: delo = 2.5%, 50%, and 97.5% levels of delosw from LGS06, adjusted for an ice-free world.

%define ice-free adjustment
icefree=-1;
%load giss data
lat=double(ncread('LeGrande_Schmidt_d18O_v1_1.nc','lat'));
lon=double(ncread('LeGrande_Schmidt_d18O_v1_1.nc','lon'));
lev=double(ncread('LeGrande_Schmidt_d18O_v1_1.nc','depth'));
delo=double(ncread('LeGrande_Schmidt_d18O_v1_1.nc','d18o'));
%remove nans
delo(delo<-1000)=NaN;
%average 0-50m levels
ind=findnearest(50,lev);
delo=nanmean(delo(:,:,1:ind),3);

%reshape grids into form for finding closest location:
delo_vec=reshape(delo,size(delo,1)*size(delo,2),1);

%vectorize locations
[A,B] = meshgrid(lon,lat);
c=cat(2,A',B');
locs=reshape(c,[],2);

%take subsets w/o the NaNs
inder_g=~isnan(delo_vec);
locs_obs=locs(inder_g,:);
vec_obs=delo_vec(inder_g);

%group into 10 degree latitude bins
edges=-90:10:90;
%gridded product
[~,bins_lg]=histc(locs_obs(:,2),edges);
%entered locs
[~,bins_obs]=histc(coords(:,2),edges);

%preallocate delo - cells for ensembles and matrix for prctiles
delo=cell(size(coords,1),1);
delosw=NaN(size(coords,1),3);

%now loop across entered coords
for i=1:size(coords,1)
    %grab all delo in bin, adjust for ice-free
    delo{i}=vec_obs(bins_lg==bins_obs(i))+icefree;
    %return prctiles
    delosw(i,:)=prctile(cell2mat(delo(i)),[2.5 50 97.5]);
end




